@@ -6,7 +6,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use Moo;
 use Config;
@@ -253,7 +253,7 @@ Chart::Kaleido - Base class for Chart::Kaleido
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -265,7 +265,7 @@ version 0.003
     END_OF_TEXT
 
     my $kaleido = Chart::Plotly::Kaleido->new();
-    $kaleido->save( file => "foo.png", plotly => decode_json($data),
+    $kaleido->save( file => "foo.png", plot => $data,
                     widht => 1024, height => 768 );
 
 =head1 DESCRIPTION
@@ -289,6 +289,12 @@ L<Alien::Plotly::Kaleido>
 
 Stephan Loyd <sloyd@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Gabor Szabo
+
+Gabor Szabo <gabor@szabgab.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2020 by Stephan Loyd.
