@@ -6,7 +6,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use Moo;
 extends 'Chart::Kaleido';
@@ -68,7 +68,7 @@ sub transform {
     my $self = shift;
     state $check = compile_named_oo(
     #<<< no perltidy
-        plotly => ( HashRef | InstanceOf["Chart::Plotly::Plot"] ),
+        plot   => ( HashRef | InstanceOf["Chart::Plotly::Plot"] ),
         format => Optional[Str],
         width  => Int,
         height => Int,
@@ -76,10 +76,10 @@ sub transform {
     #>>>
     );
     my $arg = $check->(@_);
-    my $plotly =
-        $arg->plotly->$_isa('Chart::Plotly::Plot')
-      ? $arg->plotly->TO_JSON
-      : $arg->plotly;
+    my $plot =
+        $arg->plot->$_isa('Chart::Plotly::Plot')
+      ? $arg->plot->TO_JSON
+      : $arg->plot;
     my $format = lc( $arg->format );
 
     unless ( grep { $_ eq $format } @{ $self->all_formats } ) {
@@ -92,7 +92,7 @@ sub transform {
         width  => $arg->width,
         height => $arg->height,
         scale  => $arg->scale,
-        data   => $plotly,
+        data   => $plot,
     };
     my $resp = $self->do_transform($data);
     if ( $resp->{code} != 0 ) {
@@ -109,8 +109,8 @@ sub save {
     my $self = shift;
     state $check = compile_named_oo(
     #<<< no perltidy
-        file    => Path,
-        plotly => ( HashRef | InstanceOf["Chart::Plotly::Plot"] ),
+        file   => Path,
+        plot   => ( HashRef | InstanceOf["Chart::Plotly::Plot"] ),
         format => Optional[Str],
         width  => Int,
         height => Int,
@@ -128,7 +128,7 @@ sub save {
     $format = lc($format);
 
     my $img = $self->transform(
-        plotly => $arg->plotly,
+        plot   => $arg->plot,
         format => $format,
         width  => $arg->width,
         height => $arg->height,
@@ -151,7 +151,7 @@ Chart::Kaleido::Plotly - Export static images of Plotly charts using Kaleido
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -163,7 +163,7 @@ version 0.003
     END_OF_TEXT
 
     my $kaleido = Chart::Kaleido::Plotly->new();
-    $kaleido->save( file => "foo.png", plotly => decode_json($data),
+    $kaleido->save( file => "foo.png", plot => $data,
                     width => 1024, height => 768 );
 
 =head1 DESCRIPTION
@@ -193,7 +193,7 @@ Read-only class attribute. All supported formats.
 
 =head2 transform
 
-    transform(( HashRef | InstanceOf["Chart::Plotly::Plot"] ) :$plotly,
+    transform(( HashRef | InstanceOf["Chart::Plotly::Plot"] ) :$plot,
               Optional[Str] :$format,
               Int :$width, Int :$height, Num :$scale=1)
 
@@ -202,7 +202,7 @@ Returns raw image data.
 =head2 save
 
     save(:$file,
-         ( HashRef | InstanceOf["Chart::Plotly::Plot"] ) :$plotly,
+         ( HashRef | InstanceOf["Chart::Plotly::Plot"] ) :$plot,
          Optional[Str] :$format,
          Int :$width, Int :$height, Num :$scale=1)
 
